@@ -1,5 +1,5 @@
 /*
- * CU sudo version 1.5.3 (based on Root Group sudo version 1.1)
+ * CU sudo version 1.5.4 (based on Root Group sudo version 1.1)
  *
  * This software comes with no waranty whatsoever, use at your own risk.
  *
@@ -37,7 +37,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: logging.c,v 1.85 1996/11/14 03:49:50 millert Exp $";
+static char rcsid[] = "$Id: logging.c,v 1.88 1998/01/13 04:48:42 millert Exp $";
 #endif /* lint */
 
 #include "config.h"
@@ -374,7 +374,7 @@ void log_error(code)
 	    oldend = end;
 	    end = strchr(oldend, ' ');
 
-	    if (end) {
+	    if (maxlen > 0 && end) {
 		*end = '\0';
 		if (strlen(beg) > maxlen) {
 		    /* too far, need to back up & print the line */
@@ -536,10 +536,13 @@ static void send_mail()
 static RETSIGTYPE reapchild(sig)
     int sig;
 {
+    int save_errno = errno;
+
     (void) wait(NULL);
 #ifndef POSIX_SIGNALS
     (void) signal(SIGCHLD, reapchild);
 #endif /* POSIX_SIGNALS */
+    errno = save_errno;
 }
 
 
