@@ -1,5 +1,5 @@
 /*
- *  CU sudo version 1.5.3
+ *  CU sudo version 1.5.4
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: parse.c,v 1.76 1996/11/14 02:37:16 millert Exp $";
+static char rcsid[] = "$Id: parse.c,v 1.80 1998/01/13 15:32:41 millert Exp $";
 #endif /* lint */
 
 #include "config.h"
@@ -218,7 +218,7 @@ int command_matches(cmnd, user_args, path, sudoers_args)
     static char *c;
 
     /* don't bother with pseudo commands like "validate" */
-    if (*cmnd != '/')
+    if (strchr(cmnd, '/') == NULL)
 	return(FALSE);
 
     /* only need to stat cmnd once since it never changes */
